/*******************************************************************************
*
*	Program Name:	LecTesterNET.exe
*	Module Name:	LecTesterConsole.cs
*
*	Cambridge Technology Inc. makes no warranties, either explicit or implied, 
*	with regards to the applicability of these sample source codes for an end-user 
*	application.  They are provided merely as examples on how to interface with the 
*	EC1000 API.
*
*	Description:
*		Program to test the NET interface to the EC1000 Clients
*		LecBroadcast.dll and LecSession.dll
*
*   Author:   JLV
* 
*   Environment: .NET
* 
*   Compiler:
*       - tested with Visual Studio .NET 2003
*
*******************************************************************************/

using System;
using System.IO;
using System.Threading;
using System.Windows.Forms;
using Microsoft.Win32;


/*****************************************************************************/
class MainClass 
{ 

	public static void Main(string[] args) 
	{ 
		string	strLocalIPAddress = "0.0.0.0";
		string	strFriendlyName = "" ;
		int		iServerCount = 0;


		try
		{
			ECUtils.ConsoleInit();

			ECUtils.GetLocalIPAddress(out strLocalIPAddress);

			ECBroadcast iBroadcast = new ECBroadcast(strLocalIPAddress);
			if (null != iBroadcast)
			{
				// Find all Targets in the network
				if (0 != iBroadcast.SearchEC1000s(out iServerCount, out strFriendlyName, 6))
					return;

				string[] strAddress = new string[iServerCount];	// from LECServerList
				int[] 	 iPortNumber = new int[iServerCount];	//

				// loop thru each target found
				for (int j=0; j<iServerCount; j++)
				{
					string	strData, strName;

					//	Get XML Attribute 'name' value for Element LEC from ServerList
					ECUtils.ReadFromXML(strFriendlyName, j, "LEC", "name", out strName);

					iBroadcast.ReadStatInfo(strName, out strData );
					Console.WriteLine(strData);

					// Get current Target's IPAddress and PortNumber
					iBroadcast.ReadSysInfo(strName, out strData);
					strAddress[j] = iBroadcast.strCurrECAddress;
					iPortNumber[j] = iBroadcast.iCurrECPortNumber;
					Console.WriteLine(strData);
				}

				for (int i = 0; i < iServerCount; i++)
				{
					if ( (1 == iServerCount) ||  
						( DialogResult.Yes ==
						MessageBox.Show("Want to connect to EC1000= " + strAddress[i] + " ?", 
						"LecTester program", MessageBoxButtons.YesNo) ) 
						)
					{
						ECSession iSession = new ECSession(strLocalIPAddress, strAddress[i], iPortNumber[i]);
						if (null != iSession)
						{
							if (iSession.Attach( ))
							    iSession.SessionTest( );
							iSession.Detach();
							break;
						}
					}
				}
				iBroadcast.Detach( );
			}
			ECUtils.ConsoleEnd();
		}
		catch(Exception ex)
		{
			Console.WriteLine("\nUnexpected LECBroadcast Client exception: " + ex.Message);
			MessageBox.Show("Unexpected LECBroadcast server exception:", "LecTester", MessageBoxButtons.OK);
		}
	}

} // MainClass end
