/*******************************************************************************
*
*	Program Name:	LecTesterNET.exe
*	Module Name:	LecTesterSession.cs
*
*	Copyright (c) 2007 Cambridge Technology Inc. 
*	All rights reserved
*	Cambridge Technology Inc. makes no warranties, either explicit or implied, 
*	with regards to the applicability of these sample source codes for an end-user 
*	application.  They are provided merely as examples on how to interface with the 
*	EC1000 API.
*
*	Description:
*		Program to test the NET interface to the EC1000 Clients
*		LecBroadcast.dll
*		It monitors Broadcast messages from existing EC1000 on the network
*		and list their info in the registry.  This program runs in the background
*		as a 
*
*   Author:   JLV
* 
*   Environment: .NET
* 
*   Compiler:
*       - tested with Visual Studio .NET 2003
*
*******************************************************************************/

using System;
using System.Threading;				// for Sleep
using System.IO;					// for StringReader
using LanmarkControls.LECBroadcast;


	/*****************************************************************************/
	public class ECBroadcast 
	{ 

		private ILecBroadcast iA;
		private int		piClientId;


        public string strCurrServerVer;		// from LECServerList
        public string strCurrFpgaVer;		// from LECServerList
		public string strCurrECAddress;		// from LECServerList
		public int	  iCurrECPortNumber;	//



		/*--------------------------------------------*/
		public ECBroadcast(string	strLocalAddress) 
		{ 
			string	strBroadcastAddress  = "224.168.100.2";	// from AdminConfig.xml
			int 	iBroadcastPortNumber = 11000;			//

			//			piServerCount = 0;
			//			strServerList = "";
			strCurrECAddress = "";		// from LECServerList
			iCurrECPortNumber = 0;		//

			try
			{
				ECUtils.LogWrite("Creating BROADCAST object. ");
//				Broadcast cA = new Broadcast();	// create a Broadcast Obj Instance
				Broadcast cA = Broadcast.Instance;

				ECUtils.LogWrite("Querying BROADCAST Interface. ");
				this.iA = (ILecBroadcast)cA;	// Query for a Broadcast Interface

				if ( 0 != iA.clientAttachBroadcast(strBroadcastAddress, strLocalAddress, iBroadcastPortNumber, ref piClientId) )
				{
                    ECUtils.LogWrite("\n iA.clientAttachBroadcast(" + strLocalAddress + ") FAILED. piClientId= " + piClientId);
					return;
				}
                ECUtils.LogWrite("\n iA.clientAttachBroadcast(" + strLocalAddress + ") Suceeded. piClientId= " + piClientId);
			
			}
			catch(Exception ex)
			{
				ECUtils.LogWrite("\nUnexpected LECBroadcast server exception: " + ex.Message);
			}
		}

		/*--------------------------------------------*/

		public void Detach( )
		{
			ECUtils.LogWrite("\n\n Exiting.  clientDetachBroadcast( ) ......."); 
			iA.clientDetachBroadcast(piClientId);

			Thread.Sleep(500);
		}

		/*--------------------------------------------*/

		public uint SearchEC1000s( out int iServerCount, out string strServerList, int iPollCnt )
		{
			strServerList = "";
			iServerCount = 0;
			uint iRet= 0;

            for (int i = 0; i < iPollCnt; i++)
			{
				iRet = iA.getLECServerList(piClientId, out iServerCount, out strServerList);

				Console.Write("{0}", iServerCount);
				Thread.Sleep(1000);
			}
			ECUtils.LogWrite(" - Poll found "+ iServerCount.ToString() +" target(s)\n");

			if (iServerCount == 0)
				return 1;

			return iRet;
		}

		/*--------------------------------------------*/

		public void ReadSysInfo(string strECName, out string strSysInfo )
		{
			uint	err = 0;

			strSysInfo = "";

			err = 1;
			while (0 != err)
			{
				err = iA.getBroadcastData(piClientId, strECName, 0x00000001, out strSysInfo);
				if (0 == err)
				{
//					ECUtils.LogWrite("\n\n SUCCESS iA.getBroadcastData('{0}', 0x00000001) piData=\n\n {1}\n", 
//						strECName, strSysInfo);
                    ECUtils.LogWrite("\n\n SUCCESS iA.getBroadcastData('" + strECName.ToString() + "', 0x00000001)\n");

					//	Get XML value from this Elements out of DataType 0x00000001
                    ECUtils.ReadFromXML(strSysInfo, 0, "AVer", null, out strCurrServerVer);
                    ECUtils.ReadFromXML(strSysInfo, 0, "FPGAFirmVer", null, out strCurrFpgaVer);
                    ECUtils.ReadFromXML(strSysInfo, 0, "IP", null, out strCurrECAddress);
					string	strTemp = "";
					ECUtils.ReadFromXML(strSysInfo, 0, "Port", null, out strTemp);
					iCurrECPortNumber = Convert.ToInt32(strTemp);
				}
				else
				{
					Console.Write(".");
					Thread.Sleep(1000);
				}
			}
		}

		/*--------------------------------------------*/

		public void ReadStatInfo(string strECName, out string strStatInfo )
		{
			uint	err = 0;

			strStatInfo = "";

			err = 1;
			while (0 != err)
			{
				err = iA.getBroadcastData(piClientId, strECName, 0x00000007, out strStatInfo);
				if (0 == err)
				{
//					ECUtils.LogWrite("\n\n SUCCESS iA.getBroadcastData('{0}', 0x00000007) piData=\n\n {1}\n", 
//						strECName, strStatInfo);
                    ECUtils.LogWrite("\n\n SUCCESS iA.getBroadcastData('" + strECName.ToString()+ "', 0x00000007)\n");
				}
				else
				{
					Console.Write(".");
					Thread.Sleep(1000);
				}
			}
		}


	} // ECBroadcast end


